@@ -1,16 +1,20 @@
 mod array;
 mod bool;
 mod btreemap;
+mod btreeset;
 #[cfg(feature = "chrono")]
 mod datetime;
 mod floats;
 mod hashmap;
+mod hashset;
 mod integers;
 mod optional;
 mod regex;
 mod slice;
 mod string;
 mod uri;
+#[cfg(feature = "url")]
+mod url;
 #[cfg(feature = "uuid")]
 mod uuid;
 mod vec;
